Hooks

Struct Hooks 

pub struct Hooks {
    pub log_fn: Arc<dyn Fn(CommunicationSetup) -> Option<Logger<CapacityContainerBuilder<Vec<(Duration, CommunicationEvent)>>>> + Send + Sync>,
    pub refill: BytesRefill,
    pub spill: Option<Arc<dyn Fn() -> (Box<dyn SpillPolicy>, Box<dyn SpillPolicy>) + Send + Sync>>,
}
Configuration hooks that (currently) live outside the configuration.

Fields are public so callers can mutate Hooks::default() before passing it to try_build_with.

Fields

log_fn: Arc<dyn Fn(CommunicationSetup) -> Option<Logger<CapacityContainerBuilder<Vec<(Duration, CommunicationEvent)>>>> + Send + Sync>

A mechanism to set up loggers for each communication thread.

refill: BytesRefill

A strategy for refreshing bytes for BytesSlab.

spill: Option<Arc<dyn Fn() -> (Box<dyn SpillPolicy>, Box<dyn SpillPolicy>) + Send + Sync>>

A mechanism to get a matched pair of spill policies (writer, reader) per queue.